@@ -11,7 +11,7 @@ class PyChance:
 
 
 if __name__ == '__main__':
-    from pychance.simpletable import SimpleTable
+    from pychance.data import SimpleTable
 
     test_table = SimpleTable("foo", ["bar", "baz"])
 
